package main

import (
	"context"
	"crypto/tls"
	"log"
	"io"

	"google.golang.org/grpc"
	"google.golang.org/grpc/credentials"
	"google.golang.org/grpc/metadata"

	pb "snapclient/pb"
)

func main() {

	creds := credentials.NewTLS(&tls.Config{})
	conn, err := grpc.Dial("snap-grpc.quodd.com:443", grpc.WithTransportCredentials(creds))
	if err != nil {
		log.Fatal(err)
	}
	defer conn.Close()

	client := pb.NewSnapServiceClient(conn)

	// How to get a token: https://developer.quodd.com/docs/rest-api/post-generate-a-token
	md := metadata.New(map[string]string{"Authorization": "Bearer TOKEN_HERE"})
	ctx := metadata.NewOutgoingContext(context.Background(), md)


	// SnapsRequest Example
	snapsRequest := &pb.SnapsRequest{
		Tickers: []string{"SPY", "META"},
	}
	snaps, err := client.GetSnaps(ctx, snapsRequest)
	if err != nil {
		log.Fatalf("could not get snaps: %v", err)
	}
	log.Printf("GetSnaps Response: %s", snaps)

	// SnapStreamRequest Example
	snapStreamRequest := &pb.SnapStreamRequest{
		Tickers: []string{"AAPL", "GOOG", "MSFT"},
	}

	stream, err := client.GetSnapsStream(ctx, snapStreamRequest)
	if err != nil {
		log.Fatalf("could not get snap stream: %v", err)
	}

	for {
		snap, err := stream.Recv()
		if err == io.EOF {
			break
		}
		if err != nil {
			log.Fatalf("could not receive snap message: %v", err)
		}
		log.Printf("Received Snap: %s", snap)
	}
}
